﻿using System;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.WebEdition;

public partial class _Default : System.Web.UI.Page, ICallbackEventHandler
{
    private const string latestVersion = "MapSuiteCore:3.1.16;WebEdition:3.1.16";
    private string callbackResult = string.Empty;
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!Page.IsPostBack)
        {
            CheckVersion();

            Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
            Map1.CurrentExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);
            Map1.MapUnit = GeographyUnit.DecimalDegree;

            ShapeFileFeatureLayer statesLayer = new ShapeFileFeatureLayer(MapPath("~/App_Data/states.shp"));
            statesLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 243, 239, 228), GeoColor.FromArgb(255, 218, 193, 163), 1);
            statesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            Map1.StaticOverlay.Layers.Add("StaticLayer", statesLayer);
        }
    }

    private static void CheckVersion()
    {
        if (!Map.Version.Equals(latestVersion))
        {
            throw new Exception("You are not using latest version 3.1.16.");
        }
    }

    #region ICallbackEventHandler Members

    public string GetCallbackResult()
    {
        return callbackResult;
    }

    public void RaiseCallbackEvent(string eventArgument)
    {
        string[] lonlatStrings = eventArgument.Split(',');
        PointShape lonlat = new PointShape(double.Parse(lonlatStrings[0]), double.Parse(lonlatStrings[1]));
        ShapeFileFeatureLayer statesLayer = (ShapeFileFeatureLayer)Map1.StaticOverlay.Layers["StaticLayer"];
        statesLayer.Open();
        Collection<Feature> features = statesLayer.QueryTools.GetFeaturesContaining(lonlat, ReturningColumnsType.AllColumns);

        if (features.Count > 0)
        {
            callbackResult = features[0].ColumnValues["STATE_NAME"];
        }
    }

    #endregion
}
